<?php
/**
 * @file
 * Advanced page display title.
 *
 * Copyright (c) HighWire Press, Inc.
 * This software is open-source licensed under the GNU Public License Version 2 or later
 * The full license is available in the LICENSE.TXT file at the root of this repository
 */
$plugin = array(
  'single' => TRUE,
  'icon' => 'icon_node_form.png',
  'title' => t('Advanced Page: Display Title'),
  'description' => t('Advanced page display title.'),
  'category' => t('Advanced Page'),
  'required context' => new ctools_context_required(t('Node'), 'node'),
  'render callback' => 'advanced_page_advanced_page_display_title_render',
  'edit form' => 'advanced_page_advanced_page_display_title_form',
);
/**
 * Render function for the Advanced Page Display Title content type.
 */
function advanced_page_advanced_page_display_title_render($subtype, $conf, $panel_args, &$context) {
  if (empty($context) || empty($context->data)) {
    return;
  }

  $node = $context->data;
  $type = node_type_get_type($node);
  $field_lang = field_language('node', $node, 'field_advanced_page_display_titl');

  if (!empty($node->field_advanced_page_display_titl[$field_lang][0]['value'])) {
    $title = $node->field_advanced_page_display_titl[$field_lang][0]['value'];
  }
  else {
    $title = $node->title;
  }

  $title = !empty($conf['link']) ? l($title, 'node/' . $node->nid) : check_plain($title);

  $block = new stdClass();
  $block->module  = 'advanced_page';
  $block->title = $type->title_label;
  $block->delta   = $node->nid;

  if (empty($conf['wrapper_element']) || $conf['wrapper_element'] == 'none') {
    $block->content = $title;
    return $block;
  }

  $content = array(
    '#theme' => 'html_tag',
    '#tag' => $conf['wrapper_element'],
    '#value' => $title,
    '#attributes' => array(),
  );

  if (!empty($conf['id'])) {
    $content['#attributes']['id'] = $conf['id'];
  }

  if (!empty($conf['class'])) {
    $content['#attributes']['class'] = explode(' ', $conf['class']);
  }

  $block->content = $content;

  return $block;
}
/**
 * The form to add or edit a settings.
 */
function advanced_page_advanced_page_display_title_form($form, &$form_state) {
  $conf = $form_state['conf'];

  $form['wrapper_element'] = array(
    '#title' => t('Title tag'),
    '#type' => 'select',
    '#options' => array(
      'none' => t('- No tag -'),
      'h1' => t('h1'),
      'h2' => t('h2'),
      'h3' => t('h3'),
      'h4' => t('h4'),
      'h5' => t('h5'),
      'h6' => t('h6'),
      'div' => t('div'),
      'p' => t('p'),
      'span' => t('span'),
      'strong' => t('strong'),
      'em' => t('em'),
    ),
    '#default_value' => $conf['wrapper_element'],
  );

  $form['id'] = array(
    '#title' => t('CSS id to use'),
    '#type' => 'textfield',
    '#default_value' => $conf['id'],
    '#states' => array(
      'invisible' => array(
        ':input[name="wrapper_element"]' => array('value' => 'none')
      ),
    ),
  );

  $form['class'] = array(
    '#title' => t('CSS class to use'),
    '#type' => 'textfield',
    '#default_value' => $conf['class'],
    '#states' => array(
      'invisible' => array(
        ':input[name="wrapper_element"]' => array('value' => 'none')
      ),
    ),
  );

  $form['link'] = array(
    '#title' => t('Link to node'),
    '#type' => 'checkbox',
    '#default_value' => $conf['link'],
    '#description' => t('Check here to make the title link to the node.'),
  );

  return $form;
}
/**
 * Stores the configuration settings.
 */
function advanced_page_advanced_page_display_title_form_submit($form, &$form_state) {
  form_state_values_clean($form_state);
  $form_state['conf'] = $form_state['values'];
}